Monty Python's Flying Circus: Just the Words - Episode 44

# Episode Forty-four: Mr Neutron

Post box ceremony
Mr Neutron
Teddy Salad (CIA agent)
'Conjuring Today'

Colour code: Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Animated titles. A street in Ruislip, morning. A scrap cart is going down the street.
Scrap Man | Let's bring 'em out! Any old iron! Any old iron!
| A door opens and a homewife brings out a rather sophisticated-looking ground-to-air missile system, and dumps it on the cart.
Scrap Man | Thank you.
| Another door opens and a couple of rather respectable-looking old ladies bring out two bazookas and assorted shells and put them by the gate. There are further contributions of arms from householders. A GPO van comes up the street, passes the scrap cart and comes to rest up by the camera. There is a pillar box with a cover on it on the pavement, plus a rostrum with PA and bunting. A lord mayor is ushered out of the van by a post office official. The mayor and several ladies sit on the rostrum. Clearing his throat, the GPO official gets up, tests the microphone and starts to speak in a slightly strange voice.
GPO Official | We are here today to witness the opening of a new box to replace the box which used to stand at the corner of Ulverston Road and Sandwood Crescent. Owing to the road-widening programme carried out by the Borough Council, the Ulverston Road box was removed, leaving the wall box in Esher Road as the only box for the Ulverston Road area. This new box will enable the people of the Ulverston Road area to post letters, post-cards and small packages without recourse to the Esher Road box or to the box outside the post office at Turner's Parade which many people used to use, but which has now been discontinued owing to the opening of this box and also the re-organization of box distribution throughout the whole area, which comes into force with the opening of new boxes at the Wyatt Road Post Office in July. (a moment's pause) Nous sommes ici ce matin pour loire témoin à l'ouvermre de la nouvelle boîte pour remplacer la boîte qui autrefois était placée au coin d'Ulverston Road et Sandwood Crescent. Parce que du projet pour l'élargissement de la rue qui fait par le Borough Council, la boîte dans Ulverston Road est remplacée, et la boîte de mur dans Esher Road, est la seule boîte pour le région d'Ulverston Road. Cette boîte nouvelle rendra capables les hommes d'Ulverston Road de mettre dans les poste les lettres, les carte-postales, et des petits paquets sans avant besoin de la boîte de mur dans Esher Road, ou les boîtes de la Turner's Parade bureau de poste, qui beaucoup des hommes ont fait usage mais qui est maintenant disconfinuée parce que l'ouverture de cette boîte ici, et le réorganisation régionale que commence avec l'ouverture des boîtes au bureau de poste en Wyatt Road le juillet. (a moment's pause) Wir kommen hier heute Morgen für die Einfang auf dem neue Kabinett für die Poste.
| The first two sentences of the next voice over are laid over the end of the French speech.
Voice Over | A perfectly ordinary morning in a perfectly ordinary English suburb. Life goes on as it has done for years.
| Cut to a suburban railway station.
Voice Over | But soon this quiet pattern of life was to change irrevocably. The commonplace routine of a typical Monday morning would never be the same again, for into this quiet little community came ... Mr Neutron!
| A train stops at the station. The train doors open and out steps Mr Neutron. He looks like an American footballer, with enormous shoulders, tapering to a thin waist. He has very regular features and piercing eyes and is most impressive. He stands at the door of the train for a moment. The words 'Mr Neutron' are written in bold diagonally across his chest. He carries a Sainsbury's shopping bag.
Voice Over | Mr Neutron! The most dangerous and terrifying man in the world! The man with the strength of an army! The wisdom of all the scholars in history! The man who had the power to destroy the world. (animation of planets in space) Mr Neutron. No one knows what strange and distant planet he came from, or where he was going to!... Wherever he went, terror and destruction were sure to follow.
| Cut to Neutron's garden. He has three little picnic chairs out and is having tea with Mr and Mrs Entrail, a middle-aged couple. The lady, a little overdressed dominates. Mr Entrail sits there rather sourly.
Voice Over | Mr Neutron! The man whose incredible power has made him the most feared man of all time... waits for his moment to destroy this little world utterly!
Mrs Entrail | Then there's Stanley ... he's our eldest ... he's a biochemist in Sutton. He's married to Shirley...
Mr Neutron | (in a strange disembodied voice, grammatically correct but poor in intonation) Shirley who used to be the hairdresser?
Mrs Entrail | Yes, that's right, I think she's a lovely person. (indicates her husband) My husband doesn't ... he thinks she's a bit flash.
Mr Entrail | I hate 'er! I hate 'er guts.
Mrs Entrail | And they, of course, they come down most weekends, so you'll be able to meet them then.
Mr Neutron | l'd ... love ... to. Hairdressing is very interesting.
Mrs Entrail | And very important, too. If you don't care for your scalp, you get rabies. Then there's Kenneth, he's our youngest. Mind you, he's a bit of a problem... at least my husband thinks he is, anyway.
Mr Entrail | Nasty little piece of work, he is, I hate him!
Mrs Entrail | Mind you, the one we hear so much about nowadays is Karen. She married a Canadian - he's a dentist - they live in Alberta - two lovely children, Gary who's three, Leslie who's six. They look like the spitting image of Karen. D'you want to see a photo ... ?
Mr Neutron | Oh, yes please.
Mrs Entrail | All right.
| She goes to get a photograph.
Mr Entrail | They're a couple of little bastards. I hate 'em. They've got eyes like little pigs, just like their mother. She's a disaster ... a really horrible-looking person, she is. I thought that one would stay on the shelf, but along comes this stupid dentist git. He's a real creepy little bastard, he is. I hate 'im.
Mr Neutron | This is a nice area.
Mr Entrail | It's like a bloody graveyard. I hate it.
Mr Neutron | It's handy for the shops and convenient for the West End.
Mr Entrail | If you like going to the West End. I think it's a stinking dump.
| Cut to a well-guarded American government building, with the letters 'FEAR' on a board outside.
Voice Over | Meanwhile in Washington, at the headquarters of 'FEAR' - the Federal Egg Answering Room - in reality a front name for 'FEEBLE' - the Free World Extra-Earthly Bodies Location and Extermination Centre... all was not well.
| A high-security operations room - maps, charts. monitor screens. A message comes chattering over the teleprinter. A teleprinter operator rips it out and takes it over to Captain Carpenter who sits at a control desk.
Captain Carpenter | Good God! (he grabs a red flashing phone) Get me the Supreme Commander Land, Sea and Air Forces, immediately!
| Cut to a large room, empty apart from a very large desk with a large American eagle emblem above it. We hear American military music. There is nothing on the desk, except for a very futuristic, dynamic-looking intercom. Behind the desk the supreme commander sits. After a moment, slowly and rather surreptitiously, he sniffs his left armpit inside his jacket. Then, with a quick look around to see that no one is watching, he smells the other armpit. He sits up again, then cups his hand in front of his face to smell his breath. He looks worried still. He reaches down slowly and takes his shoe off. He has just brought it up to his nose when the intercorn buzzes loudly and a light flashes. The music stops. He jumps, and quickly takes his shoe off the desk. He presses a switch on the intercom.
Commander | Hello?
Carpenter | This is Captain Carpenter sir, from FEAR.
Commander | You mean FEEBLE?
Carpenter | Yes, sir ...
Commander | What is it?
Carpenter | Mr Neutron is missing, sir!
Commander | Mr Neutron! Oh my God! OK - Surround the entire city! Send in four waves of armed paratroopers with full ground-to-air missile support! Alert all air bases! Destroy all roads! We'll bomb the town flat if we have to!
Carpenter | Sir! Sir! He's not in Washington, sir.
Commander | OK! Hold everything! Hold everything! Hold it! Lay off! Lay off... Where is he?
Carpenter | We don't know, sir ... all we know is he checked out of his hotel and took a bus to the airport.
Commander | All right! I want a full-scale Red Alert throughout the world! Surround everyone with everything we've got! Mobilize every fighting unit and every weapon we can lay our hands on! I want... I want three full-scale global nuclear alerts with every army, navy and air force unit on eternal standby!
Carpenter | Right, sir!
Commander | And introduce conscription!
Carpenter | Yes, sir!
Commander | Right!
| He slams the intercom button down and sits there. Silence again. His eyes look from side to side then slowly he goes back to smelling himself.
Voice Over | So the world was in the grip of FEAR! A huge and terrifying crisis generated by one man! (zoom into Neutron in his front garden, weeding; behind him the group of GPO people are sitting opening another box fifty yards further down from the first one; a line of six recently opened boxes stretches up the road)... easily the most dangerous man the world has ever seen, honestly. Though still biding his time, he could strike at any moment. Could he be stopped in time?
| A lady stops and chats to him.
Mrs Smailes | You've got a bit of work to do there, then.
Mr Neutron | Yes, it is a problem.
Mrs Smailes | Mrs Ottershaw never used to bother ... then of course she was very old... she was 206! Well, must be going... if you need any help I'll send Frank round. He could do with a bit of'exercise, ha! ha! ha! ha! ... Fat old bastard...
| She walks off. Neutron goes back to his weeding. Cut back to the supreme commander's office. He is sniffing himself again, only this time he has his whole shirt front pulled up and he is trying to smell under his shirt. The intercom goes. He quickly tucks his shirt in and depresses the switch.
Commander | Yes?
Carpenter | Captain Carpenter here, sir. We've been on red alert now for three days, sir, and still no sign of Mr Neutron.
Commander | Have we bombed anywhere? Have we shown 'em we got teeth?
Carpenter | Oh yes, sir. We've bombed a lot of places flat, sir.
Commander | Good. Good. We don't want anyone to think we're chicken.
Carpenter | Oh no! They don't think that, sir. Everyone's really scared of us, sir.
Commander | Of us?
Carpenter | Yes, sir.
Commander | (pleased) Of our power?
Carpenter | Oh yes, sir! They're really scared when they see those big planes come over.
Commander | Wow! I bet they are. I bet they are. I bet they're really scared.
Carpenter | Oh they are, sir.
Commander | Do we have any figures on how scared they are?
Carpenter | No ... no figures, sir. But they sure were scared.
Commander | Ah! But it's not working?
Carpenter | No, sir.
Commander | OK. We'll try another tactic. We'll try and out-smart this Neutron guy. Yes, there's one man who could nail him.
Carpenter | One guy? That won't frighten anyone, sir.
Commander | He's the most brilliant man I ever met. We were in the CIA together. He's retired now. He breeds rabbits up in the Yukon... '
Carpenter | What's his name, sir?
Commander | His name is Teddy Salad.
Carpenter | Salad as in... ?
Commander | Lettuces, cucumber, radishes. Yeah, yeah, yeah.
Carpenter | Where do I find him, sir?
Commander | The Yukon. Oh, and Carpenter ...
Carpenter | Yes, sir?
Commander | Make sure you get a decent disguise.
| Cut to the Yukon. Carpenter is trekking along. He is in ballet tights and heavy make-up with a big knapsack with 'Nothing to do with FEEBLE' on the back. He comes across a log cabin in the middle of nowhere. He presses the doorbell. A rather twee little chime. The door is opened by a huge lumberjack.
Carpenter | Oh, hello. My name's Carpenter. I'm from the US Government.
Lumberjack | Are you from the army?
Carpenter | Er... no... I'm... er... I'm... I'm from the ballet. The US Government Ballet.
| The lumberjack's eyes light up.
Lumberjack | The ballet! The ballet's coming here?
Carpenter | Well maybe...
Lumberjack | Oh, that's great! We love the ballet. Last year some of us from Yellow River got a party to go see the ballet in Montreal.
| Dimly we can see behind the lumberjack a bevy of beautiful boys of all nations.
Carpenter | Look, I was wondering...
Lumberjack | Oh, we had a marvellous time. It was Margot Fonteyn dancing 'Les Sylphides'... oh, it was so beautiful...
Carpenter | Do you know...
Lumberjack | Do you know how old she is?
Carpenter | Who?
Lumberjack | Margot Fonteyn.
Carpenter | No.
Lumberjack | She's 206!
Carpenter | Look, I hear there's a US ballet organizer round these parts by the name of Teddy Salad.
Lumberjack | You mean the special agent?
Carpenter | Well...
Lumberjack | He's an ex-CIA man. He's not a ballet dancer.
| Laughter from the boys in the hut.
Carpenter | Well, I just want to see him on some ballet business...
Lumberjack | Well, you could try the store...
Carpenter | Oh, thank you. (he turns to go)
Lumberjack | Hey! Can you get us Lionel Blair's autograph?
| Carpenter walks away.
Voice Over | While precious time was being lost in Canada, the seconds were ticking away for the free world...
| Jarring chord. Cut to Neutron's house. He is hanging flowery print wallpaper in his sitting room. Helping him is the quite enormously vast Frank Smailes who stands rather helplessly looking up at Neutron who is on a plank between two ladders.
Voice Over | Already Neutron - who, you will remember, is infinitely the most dangerous man in the world, he really is - was gathering allies together.
Mr Neutron | Try having an omelette for your evening meal... perhaps with yogurt and grapefruit.
Mr Smailes | Oh, I've tried that ... I once got down to fifty-six stone. But I couldn't stay like that. I used to take potatoes wherever I went. I used to go to the cinema with three hundredweight of King Edwards, I'd eat 'em all before I got out of the toilet. I had to go on to bread.
Mr Neutron | What about salad?
Mr Smailes | Teddy Salad?
Mr Neutron | No, no, no - salad - as in lettuces, radishes, cucumber...
| Cut to Carpenter in a log cabin trading post with trestle tables. Six Eskimos are sitting in a group at one end of the other tables. An Italian chef in a long white apron and greasy shirt, is standing over Carpenter. Carpenter sits at one table with a huge fresh salad in front of him.
Italian | You don't like it?
Carpenter | No, I didn't want to eat a salad. I wanted to find out about a man called Salad.
Italian | You're the first person to order a salad for two years. All the Eskimos eat here is fish, fish ...
First Eskimo | (very British accent) We're not Eskimos.
Second Eskimo | Where's our fish. We've finished our fish.
Italian | What fish you want today, uh?
First Eskimo | Bream please.
Italian | Bream! Where do I get a bream this time of year? You bloody choosy Eskimo pests.
First Eskimo | We are not Eskimos!
Italian | Why don't you like a nice plate of canelloni?
Eskimos | Eurrrrghhh!
First Eskimo | That's not fish.
Italian | (as he turns to go in kitchen) I've had my lot of the Arctic Circle. I wish I was back in Oldham ...
| Carpenter crosses to the Eskimos.
Carpenter | (speaking slowly, and clearly as for foreigners) Do any of you Eskimos ... speak ... English?
First Eskimo | We're not Eskimos!
Third Eskimo | I am.
Others | Sh!
Italian | (off) Haddock!
Eskimos | Where?
Carpenter | (still speaking as if to foreigners) Do any of... you ... know... a man ... called ... Salad?
First Eskimo | What, Salad as in...
Carpenter | Lettuce, cucumbers, tomatoes ... yes.
First Eskimo | Like you have on your plate?
Carpenter | Yes. That's right.
First Eskimo | No, I'm afraid not.
Second Eskimo | Where's our fish?
First Eskimo | What does this Teddy Salad do?
Carpenter | He's a... er... hen-teaser.
| Quick cut to the chairman of Fiat in his office.
Chairman | Che cosa è la stucciacatori di polli?
| SUPERIMPOSED CAPTION: 'WHAT IS A HEN-TEASER?'
| Cut back to the cabin.
First Eskimo | No, the only Teddy Salad we know is a CIA man.
Carpenter | Oh, he might know.
Eskimos | (chanting) Gunga gunga, where's our fish?
Carpenter | Where will I find him?
Second Eskimo | Oh, he lives up at Kipper Sound.
Carpenter | Thanks a lot.
Eskimos | Fishy fishy iyoooiyooo.
First Eskimo | Are you in international spying, too?
Carpenter | No... no... I'm with the... US Ballet... force... who are you with?
First Eskimo | (leans forward confidentialy) MI6. But not a word to the Eskimos.
Eskimos | Fishy fishy igooo.
| The Italian chef appears.
Italian | Here's your bloody fish.
First Eskimo | Thank you, Anouk.
Italian | I'm not an Eskimo!
| Cut to Arctic wastes - ice and snow and bitter blasting winds. Carpenter - his little tadger tiny as a tapir's tits - struggles on. He stops and peers ahead He sees a trapper figure with a sled pulled by four huskies. Carpenter hurries on and catches him up.
Carpenter | Hey! Hey!
| The man stops. On his sled are supplies including two ladies in bikinis, deep-frozen and wrapped in cellophane bags.
Carpenter | Hi! I'm Carpenter of the US Ballet.
Trapper | Hey, great to have you around. The last decent ballet we got around here was Ballet Ramben..On Thursday they did 'Petrouchka', then on Saturday they did 'Fille Mal Gardée'. I thought it was a bit slow...
Carpenter | (stopping him short) It sure is nice to see you, Mr Salad.
Trapper | I ain't Salad.
Carpenter | What?
Trapper | You want Teddy Salad?
Carpenter | Yeah ... (the man looks around rather furtively, to see if anyone is watching, then takes Carpenter's arm and indicates the dog team) I don't see anyone.
Trapper | The one on the end, on the right. That's Salad.
Carpenter | That's a dog!
Trapper | (confidentially) No only bits of it.
Carpenter | What do you mean?
Trapper | Listen, Teddy Salad is the most brilliant agent the CIA ever had, right?
Carpenter | Right.
Trapper | That's how he made his name (indicates the dog) - disguise!
| They look at the dog in silence for a moment.
Carpenter | That's incredible!
Trapper | He had to slim down to one and a half pounds to get into that costume. He cut eighteen inches off each arm and over three feet off each leg. The most brilliant surgeon in Europe stuck that tail on.
Carpenter | What about the head?
Trapper | All of the head was removed apart from the eyes and the brain in order to fit into the costume.
Carpenter | That's incredible!
Trapper | D'you want to talk to him?
Carpenter | Yeah, sure.
Trapper | (looking around him again) OK, let's move over to those trees over there... anyone might be watching.
| They pull over to a lone deciduous tree in the middle of the empty tundra wastes. They pull in. The man goes round to the dog and kneels down beside it.
Trapper | (softly) Mr Salad? ... There's Mr Carpenter to see you.
Carpenter | What does he say?
Trapper | (to Carpenter) Do you have a bone? (Carpenter feels rather helplessly in his pockets) It's all part of the disguise (he produces a bone, which he gives to the dog) OK, Teddy... here's the bone. (the dog tucks into the bone) All right, you've got his trust, now, you can talk to him.
Carpenter | (kneeling rather awkwardly down beside the dog, and speaking confidentially) Sir ... sir ... Mr Salad ... sir, I've come direct from the Commander of Land, Sea and Air Forces ... There's a pretty dangerous situation, sir. Mr Neutron... is missing. (he looks significantly at the dog, but the dog doesn't react) The General says you're the only one who'll know where to find him ... What's he say?
Trapper | He wants to go walkies.
Carpenter | Walkies?
Trapper | Yeah, he's right into it today - d'you mind taking him for walkies?
| He gives the dog to Carpenter on a lead. Carpenter hesitates and then walks off with the dog, bending down occasionally and explaining the situation.
Voice Over | While Carpenter took the most brilliant agent the CIA ever had for walkies, events in the world's capitals were moving fast!
| Cut to a picture of the outside of l0 Downing Street. Zoom in on the door. Music: 'Rule Britannia' type theme. Cut to interior - a few circular tables, dim lighting. The decor of a rather exclusive restaurant. Subdued murmur of upper-class people stuffing their faces. A gypsy violinist is going from table to table playing and singing. In the middle of all this there is the prime minister at a big leather-topped desk, covered with official papers, three telephones, an intercom, tape recorder, a photo of Eisenhower with a very small bunch of flowers in front of it in a sort of self-contained shrine, an in/out tray, blotter, etc. The intercom buzzes.
Voice | The Secretary of State to see you, Prime Minister.
Prime Minister | Very well, show him in.
| The prime minister switches off. The secretary of state enters, wending his way through the tables. He sits at the desk. He is in a rather agitated condition.
Secretary of State | Prime Minister.
Prime Minister | Do take a seat.
| He takes a seat from the next table; the lady sitting on it falls to the floor.
Secretary of State | Prime Minister, we've just had the Supreme Commander US Forces on the phone. Apparently they want a full-scale Red Alert!
Prime Minister | They what?
| The gypsy violinist has come round to the desk. He is playing a sad, slow melody and smiling encouragingly at them. They glance at him. He flashes a white smile. The secretary of state drops his voice and huddles closer to the prime minister.
Secretary of State | They want a full-scale Red Alert - every troop movement...
| As the secretary leans forward so does the gypsy, musing the secretary to break off in mid-sentence.
Prime Minister | It's all right - don't worry about Giuseppe... (the secretary looks at the gypsy who smiles again toothily) He's English really.
Secretary of State | Well apparently the whole structure of world peace may be threatened unless we immediately...
Giuseppe | (heavy accent, leaning forwards) Your anniversary, signore?
Prime Minister | No, no, Giuseppe - not now.
Giuseppe | (indicating the secretary of state) You mean zis isn't ze lady?
Prime Minister | No.
Giuseppe | Oh, signora ... my mistake! I play for you 'My Mistake'. (before the prime minister can stop him he goes into a strident Italian song) 'My mistake, I have made my mistake! What a dreadful mistake! Is this mistake that I make!' (strums violently and starts on the second verse) 'Oh my mistake...'
Prime Minister | Giuseppe, do you mind playing over there.
Giuseppe | (flashing a winning smile) Very well, signor. But I play only for you... and your beautiful companion.
| He moves off mysteriously, singing the mistake song.
Secretary of State | Well anyway, this Mr Neutron, is located somewhere in the London area. We must find and exterminate him. The Americans say if we don't, they will.
Prime Minister | (straining to hear over noise of singing) What?
Secretary of State | The Americans say if we won't they will!
Prime Minister | That he doesn't know what?
Secretary of State | They'll bomb the entire London area.
Prime Minister | (getting up) We'd better get out of here!... (he grabs the photo of Eisenhower)
Secretary of State | They won't bomb here.
Prime Minister | Are you sure?
Secretary of State | Sure.
Prime Minister | (sitting down with great relief) Right. When are they going to start?
Secretary of State | Well apparently they haven't got Neutron yet... but when they do...
| The diners have by this time joined a conga led by the gypsy violinist playing 'My Mistake'. Awfully heartily they dance past the prime minister's desk. Cut to Artic wastes. The wind howls. The trapper is sitting beside a fire, picking his nose thoughtfully and tending a stewpan. The dog bounds back, Carpenter on the end of his lead, breathless from trying to keep up.
Trapper | Well. Did he tell you anything?
Carpenter | (worn out by the walk) No ... we chased sticks ... we chased a few reindeer...
Trapper | (patting the dog) You been chasing reindeer, have you? You're a naughty boy... yes... ain't you a naughty boy...
Carpenter | Look, we haven't got much time ... He hasn't given me any information yet...
Trapper | OK. Tell you what, let's eat. You give him one of your meatballs, he'll tell you anything... OK?
Carpenter | OK.
| Suddenly the dog woofs, gets up on back legs and starts pawing the trapper.
Trapper | Wait a minute - he's trying to tell us something.
| A strangled, strained American voice comes from within the dog. Slightly muffled perhaps.
Dog | Carpenter ... er ... ugh ... ah...Carpenter...
Carpenter | (kneeling down and peering into the dog's face) Yes, Mr Salad? Can you hear me?
Dog | Yes... yes... it's just it's so goddam painful in here... what's the problem?
Carpenter | It's Mr Neutron, sir ... he's gone missing. The Supreme Commander wants you to take charge.
Dog | I ... oh God ... I ... I ... I...
Carpenter | Yes, Mr Salad?
Dog | I gotta go walkies again.
| Cut to the office of the supreme commander. He is now nude behind his desk. A kidney bowl full of water is on desk; he is dabbing at himself with a sponge. The intercom buzzes. He switches it on.
Voice | Still no sign of Captain Carpenter, sir... or Mr Neutron.
Commander | OK. We'll bomb Neutron out. Get me Moscow! Peking! and Shanklin, Isle of Wight!
| Cut to stock film of B52s on a bombing raid.
Voice Over | And so the Great Powers and the people of Shanklin, Isle of Wight, drew their net in ever-tightening circles around the most dangerous threat to peace the world has ever faced. They bombed Cairo, Bangkok, Cape Town, Buenos Aires, Harrow, Hammersmith, Stepney, Wandsworth and Enfield... But always it was the wrong place.
| Cut to an area of smoking rubble. A van with the words 'US Air Force' on the side trundles through the rubble. It has a loudspeaker on the top of it.
Loudspeaker | Sorry Enfield!... We apologize for any inconvenience caused by our bombing... sorry...
Voice Over | But what of Mr Neutron, the most fearfully dangerous man in the world! The man who could destroy entire galaxies with his wrist, the man who could tear fruit machines apart with his eyeballs... He had not been idle!
| Meantime we have mixed through to Neutron's suburban sitting room. He is standing in the doorway gazing at something off camera. He holds an envelope which he has just opened and a letter.
Voice Over | In fact he had fallen in love... with the lady who 'does' for Mrs Entrail...
| The camera pans across to a slovenly char in paisley apron, furry slippers and head scarf. Throughout this scene we hear the sound of bombers and the distant muffled sound of explosions.
Mrs Scum | Oh 'ello Mr N, terrible about Enfield, innit? It's all gone. So's Staines ... lovely shops they used to have in Staines... and Stunmore, where the AA offices used to be. I don't know where we'll pay our AA subscriptions to now. Do you know where we'll have to pay our AA. subscriptions to now, Mr N?
Mr Neutron | I didn't know you were a member of the AA Mrs S.C.U.M.
Mrs Scum | Oh yes. Ever since the Corsair broke down in Leyonstone ... they towed it all the way to Deauville FOC. (Mr Neutron looks blank) Free of Charge. Well my husband Ken, K.E.N., he said...
Mr Neutron | Oh, forget about your husband, Mrs S.C.U.M. - or may I call you Mrs S?
Mrs Scum | You can call me Linda, if you like.
Mr Neutron | No, I'd rather call you Mrs S.
Mrs Scum | Oh...
Mr Neutron | (as if trying to soften the blow) And you can call me Mr N.
Mrs Scum | Well... that's what I was calling you.
Mr Neutron | Mrs S, there is something I have to tell you...
Mrs Scum | Yes, Mr N?
Mr Neutron | I have just won a Kellogg's Corn Flake Competition.
Mrs Scum | Oh Mr N! That's wonderful!
Mr Neutron | I got the ball in exactly the right place. The prize is £5,000 in cash, or as much ice cream as you can eat.
| Her eyes go round as saucers and all thoughts of returning to her marital bed vanish under the impact of such imminent wealth.
Mrs Scum | £5,000!
Mr Neutron | I was thinking of taking the ice cream.
Mrs Scum | (alarmed) Oh no!
Mr Neutron | It's been so hot recently.
Mrs Scum | You couldn't eat that much ice cream Mr N.
Mr Neutron | Mrs S, I can eat enormous quantifies of ice cream without being sick.
Mrs Scum | Oh no! Take the £5,000! Please take the £5,000.
Mr Neutron | I was thinking. If we got married...
Mrs Scum | Oh yes! (she sits very close to him)
Mr Neutron | We could use the £5,000 to buy a spoon...
Mrs Scum | Oh! We could buy a lot more than that!
Mr Neutron | And then fill up with ice cream.
Mrs Scum | No! Forget about the ice cream. We need the money.
Mr Neutron | We need nothing. For there is something I have not told you Mrs S.C.U.M.
Mrs Scum | Oh please call me Mrs S.
Mr Neutron | No I would rather go back to calling you Mrs S.C.U.M., Mrs S.C.U.M. I am the most powerful man in the universe. There is nothing I cannot do.
Mrs Scum | Oh Mr N.
Mr Neutron | I want you to be my helpmate. As Tarzan had his Jane, as Napoleon had his Josephine, as Frankie Laine had whoever he had, I want you to help me in my plan to dominate the world!
Mrs Scum | Oh Mr N. That I should be so lucky!
Mr Neutron | You're not Jewish are you?
| Cut back to the Yukon. The trapper, Captain Carpenter and the dog are still sitting round the dying campfire over the remains of supper. They are all looking a little bit bored. The dog has obviously been telling long reminiscences.
Dog | Another time when I was in Cairo, I was disguised as a water hydrant. The whole top part of my head had been removed and...
Carpenter | Please, Mr Salad .... you must tell us where Neutron is.
Dog | And I functioned! D'you hear? I really worked. I could put out a fire.
Carpenter | Please, Mr Salad...
Dog | Mind you, it hurt a bit...
Carpenter | Please, Mr Salad - there isn't much time. Where will we find Neutron?
Dog | OK. Give me another meatball and I'll tell you.
| Carpenter grabs a meatball and throws it down for the dog. The dog wolfs it. Carpenter and Trapper exchange glances. Carpenter bends nearer the dog. The dog finishes the meatball with much slurping. Carpenter crouches beside him patiently.
Dog | OK listen carefully... I won't repeat this. You understand?
Carpenter | Yes yes - quick.
Dog | I know where Neutron is right now. I know the exact address and the exact house and the exact road...
Carpenter | OK where is he?
Dog | He's not in America...
Carpenter | No?
Dog | He's not in... Asia!
Carpenter | No?
Dog | He's not in.., Australia!
Carpenter | No?
Dog | He's in... Europe!
Carpenter | Yeah?
Dog | And you wanna know where in Europe?
Carpenter | Yeah!
Dog | OK. OK, I'll tell you. He's in England... In London... at Number 19...
| A sudden explosion completely engulfs them. Cut to the supreme commander's offce. He is still nude and has an enormous display of talcs and powders on his desk. He is talking to the intercom.
Commander | OK. That's the Yukon - what's left?
Voice | Only Ruislip, the Gobi Desert, and your office, sir.
Commander | OK! Let's start with my office. (a big explosion)
| Cut to the Gobi Desert. Sweltering heat. We come onto a group opening a GPO box. There is a line of boxes stretching into the distance as far as the eye can see. Arabic is being spoken by the GPO official.
GPO Official | Ankwat i odr inkerat Gobi Desert Ulverston Road...
| SUBTITLE: 'THIS NEW BOX COMPLETES THE ENCIRCLEMENT OF THE GOBI DESERT'
GPO Official | Ik artwar, hyaddin... (etc.)
| SUBTITLE: 'THE POST OFFICE IS NOW IN A POSITION TO ACHIEVE COMPLETE WORLD DOMINATION'
| A terrific explosion. Cut to Neutron and Mrs Scum.
Mr Neutron | I will take you away from all this Mrs S.C.U.M.
Mrs Scum | Oh, Mr N... I'd follow you anywhere.
Mr Neutron | We will have two weeks in Benidorm.
Mrs Scum | Oh yes ... yes.
Mr Neutron | And I will make you the most beautiful woman in the world.
| He stretches out his hands towards her. His piercing eyes narrow in concentration. There is a flash, a jump cut, and Mrs S stands before him as dumpy and unattractive as ever, but in a brand new C & A twin set and pearls, a nice new handbag, and a rather fussy hat.
Mrs Scum | Oh... it's beautiful... oh, Mr N, you have made my heart sing... (quick cut to stock film of bomber then back to Mrs Scum) Late in life's pageant it may be ... but you have made roses bloom anew for me... (quick flash of bomber then back to Mrs Scum) Life's rich harvest is being...
Mr Neutron | Shut up, Mrs S. We must hurry...
| He takes her hand and pulls her away.
Mrs Scum | I'd better leave a note for Ken... he'll be expecting us... (explosion)
| ANIMATION: the world destroyed and burning.
Voice Over | Has Mr Neutron escaped in time? Is the world utterly destroyed? How can Mr Neutron and his child bride survive? Will his mighty powers be of any avail against the holocaust? Stay tuned to this channel.
| Cut to a man in a grey suit in a studio.
Man | Hello. Well in fact what happens is that they are saved by Mr Neutron's mighty powers just as the last bomb falls on Ruislip.
| SUPERIMPOSED CAPTION: 'A MAN FROM THE "RADIO TIMES"'
Man | However, the Earth has been blown off its axis, and in a most dramatic and dangerous and expensive sequence, it spins off into space. There are appallingly expensive scenes of devastation and horror and the final incredibly expensive climax is reached as thousands of ape monsters in very expensive costumes descend from the sky onto these, plug up a whole city which has to be specially built and fling them all into the sea very expensively. And we can see those very expensive scenes right now. (the credits start on his TV set) Just after the credits have gone through... incidentally, these are going to be the most expensive and lavish scenes ever filmed by the BBC in conjunction with Time-Life of course ... these are some of the technical people who have been involved in filming these very expensive scenes, expensive sound, expensive visual effects there, expensive production assistant, expensive designer... cheap director. Well you can see those expensive scenes right now.
| CAPTION: 'THE END'
Man | (voice over) Oh come on you can give us another minute, Mr Cotton, please.
| CAPTION: 'CONJURING TODAY'
| Fade up on a conjurer with a fright wig and ping-pong eyes. He holds a bloodstained saw.
Conjurer | Good evening, last week we learned how to saw a lady in half. This week we're going to learn how to saw a lady into three bits and dispose of the body...
| Two policemen chase him off the set. They run past the man from the previous announcement who is on the phone. On his TV set we see the policemen pursuing the conjurer.
Man | Look if you can put on rubbish like that, and 'Horse of the Year Show', you can afford us another minute, Mr Cotton, please, I mean look at this load of old... (fades out)
| Fade up on the entrance to TV Centre. The man walks out.
Voice Over | World Domination t-shirts are available from BBC, World Domination Department, Cardiff.
| A man (Terry J) hits him on the head with an absolutely enormous hammer. He falls, stunned. Fade out.